***********************************************************************
** Paper ASSET EXEMPTION IN BANKRUPTCY, ACCESS TO AND COST OF CREDIT **
***********************************************************************
* by Pasqualina Arca, Gianfranco Atzeni, Luca G. Deidda

** Variable labels

label var loanrate "Interest rate on loan (%)"
label var collatgiven "Dummy=1 if firm posted collateral"
label var collatnogiven "Dummy=1 if firm not posted collateral"
label var ratetype "Dummy=1 if Fixed interest rate"
label var size "Natural log of total sales"
label var ownersExper "Owner managing experience (n. of years)"
label var HHI "Banking market concentration: Dummy=1 if Herfindahl index>1800"
label var maturity "Loan original maturity (n. of months)"
label var grantOnTapp "Amount granted over total applied"
label var company "Dummy=1 if firm has limited liability"
label var somtrat "Dummy=1 if firm has been rationed sometimes"
label var exlevnew "Average exemption level across US census divisions ($)"
label var whexlev "Homestead exemption level weighted by share of SMEs by state"
label var nonration "Financed always or sometimes"
label var minority "Dummy=1 if Owner belongs to ethinc minority"
label var owntotpw "Owner's total personal wealth"
label var owndelinq "Dummy=1 if Owner has delinquency records"
label var fem "Dummy=1 if Owner is a woman"
label var potborr "Potential borrowers (not always apply for credit)"
label var debtfinOnDebt "Financial debts on total liabilities"
label var liqOnAss "Liquidity on total assets"
label var grwsales "Dummy=1 if sales increased wrt last year"
label var deliqobbl "Dummy=1 if firm has delinquency records"
label var firmage "Firm's Age"
label var debtOnEq "Debts on equity"
label var hcredscor "Dummy=1 if firm's Credit score is top 25%"
label var newline "Dummy=1 if lending was a new line of credit"
label var black "Dummy=1 if Owner is black"
label var othminority "Dummy=1 if Owner belongs to an ethnic minority other than black"
label var mort "Dummy=1 if lending was a mortgage"
label var numapp "Number of credit applications"
label var lenghtrel "Years of firm bank relationship"
label var dist "Distance of firm from bank (miles)"
label var debtonass "Debt on total asset"
label var own_family "Dummy=1 if firm is family owned"
label var financed "Dummy=1 if firm is financed with or without collateral"
label var r12 "Total Asset"
label var asset "Total Asset - thousands of $"
label var collhhppex "Dummy=1 if firm post collateral in areas with high exemption"
label var hhppexlev "Dummy=1 if firm located in high exemption areas"



** Table 1. Loan rate and fraction of rationed firms by exemption, collateral and assets

clear
use "bkrupt11.dta"


** Any asset, column FS
reg loanrate collatgiven collhhppex ratetype newline hcredscor  numapp  size HHI ownersExper fem black othmino lenghtrel dist  debtonass own_family collatgiven asset i.a0_sic2_fin if debtonass>=0 & imp==1
sort collatgiven
by collatgiven: fsum loanrate somtrat if e(sample), stats(mean sd) f(10.3) uselabel
fsum loanrate somtrat if e(sample), stats(mean sd) f(10.3) uselabel

** Any Asset, column LEX
reg loanrate collatgiven collhhppex ratetype newline hcredscor  numapp  size HHI ownersExper fem black othmino lenghtrel dist  debtonass own_family collatgiven asset i.a0_sic2_fin if hppexlev_1<=394180 & debtonass>=0 & imp==1
sort collatgiven
by collatgiven: fsum loanrate somtrat if e(sample), stats(mean sd) f(10.3) uselabel
fsum loanrate somtrat if e(sample), stats(mean sd) f(10.3) uselabel

** Any Asset, column HEX
reg loanrate collatgiven collhhppex ratetype newline hcredscor  numapp  size HHI ownersExper fem black othmino lenghtrel dist  debtonass own_family collatgiven asset i.a0_sic2_fin if hppexlev_1>394180 & debtonass>=0 & imp==1
sort collatgiven
by collatgiven: fsum loanrate somtrat if e(sample), stats(mean sd) f(10.3) uselabel
fsum loanrate somtrat if e(sample), stats(mean sd) f(10.3) uselabel
     
** Low Asset, column FS
reg loanrate collatgiven collhhppex ratetype newline hcredscor  numapp  size HHI ownersExper fem black othmino lenghtrel dist  debtonass own_family collatgiven asset i.a0_sic2_fin if r12<2351000 & r12>0 & debtonass>=0 & imp==1
sort collatgiven
by collatgiven: fsum loanrate somtrat if e(sample), stats(mean sd) f(10.3) uselabel
fsum loanrate somtrat if e(sample), stats(mean sd) f(10.3) uselabel

** Low Asset, column LEX
reg loanrate collatgiven collhhppex ratetype newline hcredscor  numapp  size HHI ownersExper fem black othmino lenghtrel dist  debtonass own_family collatgiven asset i.a0_sic2_fin if r12<2351000 & r12>0 & hppexlev_1<=394180 & debtonass>=0 & imp==1
sort collatgiven
by collatgiven: fsum loanrate somtrat if e(sample), stats(mean sd) f(10.3) uselabel
fsum loanrate somtrat if e(sample), stats(mean sd) f(10.3) uselabel

** Low Asset, column HEX
reg loanrate collatgiven collhhppex ratetype newline hcredscor  numapp  size HHI ownersExper fem black othmino lenghtrel dist  debtonass own_family collatgiven asset i.a0_sic2_fin if r12<2351000 & r12>0 & hppexlev_1>394180 & debtonass>=0 & imp==1
sort collatgiven
by collatgiven: fsum loanrate somtrat if e(sample), stats(mean sd) f(10.3) uselabel
fsum loanrate somtrat if e(sample), stats(mean sd) f(10.3) uselabel

** High Asset, column FS
reg loanrate collatgiven collhhppex ratetype newline hcredscor  numapp  size HHI ownersExper fem black othmino lenghtrel dist  debtonass own_family collatgiven asset i.a0_sic2_fin if r12>=2351000 & r12>0 & debtonass>=0 & imp==1
sort collatgiven
by collatgiven: fsum loanrate somtrat if e(sample), stats(mean sd) f(10.3) uselabel
fsum loanrate somtrat if e(sample), stats(mean sd) f(10.3) uselabel

** High Asset, column LEX
reg loanrate collatgiven collhhppex ratetype newline hcredscor  numapp  size HHI ownersExper fem black othmino lenghtrel dist  debtonass own_family collatgiven asset i.a0_sic2_fin if r12>=2351000 & r12>0 & hppexlev_1<=394180 & debtonass>=0 & imp==1
sort collatgiven
by collatgiven: fsum loanrate somtrat if e(sample), stats(mean sd) f(10.3) uselabel
fsum loanrate somtrat if e(sample), stats(mean sd) f(10.3) uselabel

** High Asset, column HEX
reg loanrate collatgiven collhhppex ratetype newline hcredscor  numapp  size HHI ownersExper fem black othmino lenghtrel dist  debtonass own_family collatgiven asset i.a0_sic2_fin if r12>=2351000 & r12>0 & hppexlev_1>394180 & debtonass>=0 & imp==1
sort collatgiven
by collatgiven: fsum loanrate somtrat if e(sample), stats(mean sd) f(10.9) uselabel
fsum loanrate somtrat if e(sample), stats(mean sd) f(10.3) uselabel


** Table 2. Firms and owners' characteristics by exemption level
clear
use "bkrupt11.dta"
** Dummy=1 if company has limited liability
gen limliability=b3>2

** Dummy=1 if Owner owns home
gen ownhome=u7
recode ownhome -9999999994=. 
recode ownhome 2=0

** Owner other net worth
gen ownnetworth=u8

sort hhppexlev
by hhppexlev: sum asset owntotpw ownhome ownnetworth limliability if owntotpw>=0 & debtOnEq>=0 & debtonass>=0 & asset>=0


tabstat asset owntotpw ownhome ownnetworth limliability if owntotpw>=0 & debtOnEq>=0 & debtonass>=0 & asset>=0, by(hhppexlev) statistics(mean n) column(statistics) format ( %9.2g) varwidth(15)


** Table 3 - Cost of credit 

* column (1) 
clear
use "bkrupt11.dta"


reg Rb hhppexlev collatgiven collhhppex hcredscor ratetype newline  HHI  ownersExper black othmino fem /// 
own_family numapp lenghtrel dist size debtonass asset  i.a0_sic2_fin if debtonass>=0

* column (2) 

*** This import data in MI format (see mi import command help)
clear
use "bkrupt11.dta"
** Sectoral dummies
tabulate a0_sic2_fin, gen(sect)
sort imp
by imp: gen firmid=_n
keep Rb ratetype newline mort hcredscor numapp numinst size HHI ownersExper fem black othmino lenghtrel dist debtonass own_family asset ///
fincoll hcredscor maturity grantOnTapp company hppexlev_1 imp firmid apply owntotpw profit firmbkrupt ///
deliqobbl creditScore family distfirst credworth owntotpw profit firmbkrupt debtOnEq imrcw hhppexlev collatgiven collhppex financed collhhppex a0_sic2_fin sect1 sect2 sect3 sect4 sect5 sect6 sect7 sect8 sect9 sect10 sect11 sect12 sect13 sect14 sect15 sect16 sect17 sect18 sect19 sect20 sect21 sect22 sect23 sect24 sect25 sect26 sect27 sect28 sect29 sect30 sect31 sect32 sect33 sect34 sect35 sect36 sect37 sect38 sect39 sect40 sect41 sect42 sect43 sect44 sect45 sect46 sect47 sect48 sect49 sect50 sect51 sect52 sect53 sect54 sect55 sect56 sect57 sect58 sect59
save "bkrupt11_prova.dta", replace
clear
use "bkrupt11_prova.dta"
mi import flong, m(imp) id(firmid) 

** This estimates taking into account that dataset has multpile imputations

mi estimate, esampvaryok: reg Rb hhppexlev collatgiven collhhppex hcredscor ratetype newline  HHI  ownersExper black othmino fem /// 
own_family numapp lenghtrel dist size debtonass asset sect1 sect2 sect3 sect4 sect5 sect6 sect7 sect8 sect9 sect10 sect11 sect12 sect13 sect14 sect15 sect16 sect17 sect18 sect19 sect20 sect21 sect22 sect23 sect24 sect25 sect26 sect27 sect28 sect29 sect30 sect31 sect32 sect33 sect34 sect35 sect36 sect37 sect38 sect39 sect40 sect41 sect42 sect43 sect44 sect45 sect46 sect47 sect48 sect49 sect50 sect51 sect52 sect53 sect54 sect55 sect56 sect57 sect58 sect59 if debtonass>=0


** Table 4 Probability to post collateral

probit collatgiven hcredscor maturity grantOnTapp HHI company fem lenghtrel own_family  if debtonass>=0, noconstant


** Table 5: Cost of credit - Switching regression
clear
use "bkrupt11.dta"

** Calculation of IMR - Non selection hazard (hazard rate of not posting C)
  drop lptrcrd_nc imr_nc
  predict lptrcrd_nc, xb
  gen imr_nc=(normalden(-lptrcrd_nc) / normal(-lptrcrd_nc))
  label var imr_nc "Inverse Mills ratio \lambda_{NC}"
  
** Calculation of IMR Selection hazard (hazard rate posting C)

  drop lptrcrd_c imr_c
  predict lptrcrd_c, xb
  gen imr_c=-(normalden(-lptrcrd_c) /(1- normal(-lptrcrd_c)))
  label var imr_c "Inverse Mills ratio \lambda_{C}"

* column (1)
  
reg Rb imr_nc hhppexlev i.hhppexlev#c.asset asset   hcredscor ratetype newline  HHI  ownersExper black othmino fem /// 
own_family numapp lenghtrel dist size debtonass  if debtonass>=0 & collatgiven==0
drop Rl1
predict Rl1, xb

* column (2)

reg Rb  imr_c hhppexlev i.hhppexlev#c.asset asset   hcredscor ratetype newline HHI ownersExper black othmino fem /// 
own_family numapp lenghtrel dist size debtonass  if debtonass>=0 & collatgiven==1  
drop Rh1
predict Rh1, xb


* column (3)
reg Rb imr_nc hhppexlev i.hhppexlev#c.asset asset   hcredscor ratetype newline  HHI  ownersExper black othmino fem /// 
own_family numapp lenghtrel dist size debtonass i.a0_sic2_fin if debtonass>=0 & collatgiven==0

* column (4)
reg Rb  imr_c hhppexlev i.hhppexlev#c.asset asset   hcredscor ratetype newline HHI ownersExper black othmino fem /// 
own_family numapp lenghtrel dist size debtonass i.a0_sic2_fin if debtonass>=0 & collatgiven==1


** Table 6: Probability of having access to credit - marginal effects
clear
use "bkrupt11.dta"

drop ratiorate
gen ratiorate=Rl1/Rh1

* column (1)
probit financed hhppexlev collatgiven  collhhppex ratiorate maturity grantOnTapp lenghtrel hcredscor ///
deliqobbl debtOnEq company asset i.a0_sic2_fin if  debtonass>=0 
margins, dydx(hhppexlev collatgiven  collhhppex ratiorate maturity grantOnTapp lenghtrel hcredscor ///
deliqobbl debtOnEq company asset) 

* column (2)
*** this import data in MI format (see mi import command help)
clear
use "bkrupt11.dta"
** Sectoral dummies
tabulate a0_sic2_fin, gen(sect)
sort imp
by imp: gen firmid=_n
keep Rb ratetype newline mort hcredscor numapp numinst size HHI ownersExper fem black othmino lenghtrel dist debtonass own_family asset ///
fincoll hcredscor maturity grantOnTapp company hppexlev_1 imp firmid apply owntotpw profit firmbkrupt ///
deliqobbl creditScore family distfirst credworth owntotpw profit firmbkrupt debtOnEq imrcw hhppexlev collatgiven collhppex financed collhhppex  ratiorate ratiorateL   a0_sic2_fin sect1 sect2 sect3 sect4 sect5 sect6 sect7 sect8 sect9 sect10 sect11 sect12 sect13 sect14 sect15 sect16 sect17 sect18 sect19 sect20 sect21 sect22 sect23 sect24 sect25 sect26 sect27 sect28 sect29 sect30 sect31 sect32 sect33 sect34 sect35 sect36 sect37 sect38 sect39 sect40 sect41 sect42 sect43 sect44 sect45 sect46 sect47 sect48 sect49 sect50 sect51 sect52 sect53 sect54 sect55 sect56 sect57 sect58 sect59
save "bkrupt11_prova.dta", replace
clear
use "bkrupt11_prova.dta"
mi import flong, m(imp) id(firmid) 

** This estimates the marginal effects considering multiple imputations

program mimeff1, eclass properties(mi)
probit financed hhppexlev collatgiven collhhppex ratiorate maturity grantOnTapp lenghtrel hcredscor deliqobbl debtOnEq company asset  sect1 sect2 sect3 sect4 sect5 sect6 sect7 sect8 sect9 sect10 sect11 sect12 sect13 sect14 sect15 sect16 sect17 sect18 sect19 sect20 sect21 sect22 sect23 sect24 sect25 sect26 sect27 sect28 sect29 sect30 sect31 sect32 sect33 sect34 sect35 sect36 sect37 sect38 sect39 sect40 sect41 sect42 sect43 sect44 sect45 sect46 sect47 sect48 sect49 sect50 sect51 sect52 sect53 sect54 sect55 sect56 sect57 sect58 sect59 if  debtonass>=0
margins, ///
atmeans dydx(hhppexlev collatgiven collhhppex ratiorate maturity grantOnTapp lenghtrel hcredscor deliqobbl debtOnEq company asset sect1 sect2 sect3 sect4 sect5 sect6 sect7 sect8 sect9 sect10 sect11 sect12 sect13 sect14 sect15 sect16 sect17 sect18 sect19 sect20 sect21 sect22 sect23 sect24 sect25 sect26 sect27 sect28 sect29 sect30 sect31 sect32 sect33 sect34 sect35 sect36 sect37 sect38 sect39 sect40 sect41 sect42 sect43 sect44 sect45 sect46 sect47 sect48 sect49 sect50 sect51 sect52 sect53 sect54 sect55 sect56 sect57 sect58 sect59) post
end
mi estimate, esampvaryok cmdok: mimeff1 1
program drop mimeff1


